////////////////////////////////////////////////////////////
// DiskUtil class implementation
//   Demo class for ObjectOrientedProgramming
//   02/28/04 - Burns
#include "DiskUtils.h"

////////////////////////////////////////////////////////////
// Constructor/Destructors
DiskUtil::DiskUtil()
{
  
  hFind = NULL;
  this->getCurrentDirectory();
}

DiskUtil::~DiskUtil()
{
  if ( hFind != 0 )
  {
    FindClose( hFind );
  }
}
////////////////////////////////////////////////////////////

////////////////////////////////////////////////////////////
// setCurrentDirectory
//  IN pathName - directory to change to
//  RETURN      - this pointer
DiskUtil& DiskUtil::setCurrentDirectory( const char* pathName )
{
  if ( pathName != 0 )
  {
    strcpy( _currentDirectory, pathName );
    SetCurrentDirectory( _currentDirectory );
  }
  return *this;
}

////////////////////////////////////////////////////////////
// getCurrentDirectory
//  RETURN      - current directory
const char* DiskUtil::getCurrentDirectory()
{
  GetCurrentDirectory( MAX_STRING_LEN, _currentDirectory );
  return _currentDirectory;
}

////////////////////////////////////////////////////////////
// makeDirectory
//  IN pathName - directory to create
//  RETURN      - true/false - success
bool DiskUtil::makeDirectory( const char* pathName )
{
  long retval = CreateDirectory( pathName, NULL );
  return ( ( retval != 0 ) ? true : false );
}


////////////////////////////////////////////////////////////
// removeDirectory
//  IN pathName - directory to remove
//  RETURN      - true/false - success
bool DiskUtil::removeDirectory( const char* pathName )
{
  long retval = RemoveDirectory( pathName );
  return ( ( retval != 0 ) ? true : false );
}

////////////////////////////////////////////////////////////
// createFile
//  IN fileName   - file to create
//  IN bufferSize - size of content to write
//                  (if 0, an empty file is created)
//  IN content    - content to write to file
//  RETURN        - the number of bytes written to file
long DiskUtil::createFile( const char* fileName, long bufferSize, const char* content )
{
  HANDLE hFile;
  hFile = CreateFile( fileName, GENERIC_WRITE, 0, NULL, 
            CREATE_ALWAYS, FILE_ATTRIBUTE_NORMAL, NULL);
  if ( hFile != INVALID_HANDLE_VALUE )
  {
    unsigned long buffWritten;
    if ( bufferSize != 0 )
    {
      WriteFile( hFile, (void*)content, bufferSize, &buffWritten, NULL );
    }
    CloseHandle( hFile );
    return buffWritten;
  }
  return false;
}

////////////////////////////////////////////////////////////
// getFile
//  IN fileName   - file to get
//  IN bufferSize - max size of content to read
//  IN content    - content read from file
//  RETURN        - the number of bytes read from file
long DiskUtil::getFile( const char* fileName, long bufferSize, char* content )
{
  HANDLE hFile;
  hFile = CreateFile( fileName, GENERIC_READ, FILE_SHARE_READ,
            NULL, OPEN_EXISTING, 0, NULL);
  if ( ( hFile != INVALID_HANDLE_VALUE ) && ( bufferSize > 0 ) )
  {
    unsigned long buffRead;
    ReadFile( hFile, content, bufferSize, &buffRead, NULL );
    CloseHandle( hFile );
    return buffRead;
  }
  return 0;
}

////////////////////////////////////////////////////////////
// copyFile
//  IN sourceFileName - file to copy
//  IN destFileName   - file to write
//  RETURN            - true/false - success
bool DiskUtil::copyFile( const char* sourceFileName, const char* destFileName )
{
  long retval = CopyFile( sourceFileName, destFileName, FALSE );
  return ( ( retval != 0 ) ? true : false );
}

////////////////////////////////////////////////////////////
// copyFile
//  IN sourceFileName - file to delete
//  RETURN            - true/false - success
bool DiskUtil::deleteFile( const char* fileName)
{
  long retval = DeleteFile( fileName );
  return ( ( retval != 0 ) ? true : false );
}

////////////////////////////////////////////////////////////
// copyFile
//  IN sourceFileName - file to move
//  IN destFileName   - file's destination
//  RETURN            - true/false - success
bool DiskUtil::moveFile( const char* sourceFileName, const char* destFileName )
{
  long retval = MoveFile( sourceFileName, destFileName );
  return ( ( retval != 0 ) ? true : false );
}

////////////////////////////////////////////////////////////
// copyFile
//  IN sourceFileName - file to rename
//  IN destFileName   - file's new name
//  RETURN            - true/false - success
bool DiskUtil::renameFile( const char* currentFileName, const char* newFileName )
{
  return this->moveFile( currentFileName, newFileName );
}


////////////////////////////////////////////////////////////
// getFirstFileInDirectory
//  OUT fileName    - first file retrieved
//  IN file pattern - <optional> file pattern to look for (ex *.jpg )
//  OUT sysTime     - <optional> the creation time of the file
//  RETURN          - true/false - success (file found?)
bool DiskUtil::getFirstFileInDirectory( char* fileName, const char* pattern, SYSTEMTIME* sysTime )
{
  if ( hFind != 0 )
  {
    FindClose( hFind );
  }
  if ( fileName != 0 )
  {
    hFind = FindFirstFile( pattern, &findData);
    if ( hFind != 0 )
    {
      strcpy( fileName, findData.cFileName );
      if ( sysTime != NULL )
      {
        FileTimeToSystemTime( &findData.ftCreationTime, sysTime );
      }      
      return true;
    }
  }
  return false;
}

////////////////////////////////////////////////////////////
// getNextFileInDirectory
//  this must be preceeded by a getFirstFileInDirectory call
//  OUT fileName    - next file retrieved
//  OUT sysTime     - <optional> the creation time of the file
//  RETURN          - true/false - success (any more files?)
bool DiskUtil::getNextFileInDirectory ( char* fileName, SYSTEMTIME* sysTime )
{
  if ( ( hFind != NULL ) && ( fileName != 0 ) )
  {
    long retval = FindNextFile( hFind, &findData );
    if ( retval != 0 )
    {
      strcpy( fileName, findData.cFileName );
      if ( sysTime != NULL )
      {
        FileTimeToSystemTime( &findData.ftCreationTime, sysTime );
      }
      return true;
    }
  }
  FindClose( hFind );
  hFind = NULL;
  return false;
}
////////////////////////////////////////////////////////////